@@ -66,10 +66,20 @@ compute_stack.data.frame <- function(x, stack_var = NULL, group_var = NULL) {
   # This is like mutate(x, stack_upr_ = cumsum(stack_var[[2]]),
   #                     stack_lwr_ = lag(stack_upr_, default = 0))
   # but with value of stack_var in the right place.
-  args <- list(
-    stack_upr_ = bquote(cumsum(.(stack_var[[2]]))),
-    stack_lwr_ = bquote(lag(stack_upr_, default = 0))
-  )
+
+  # dplyr 0.4.2 overrides lag instead of overriding default method AND
+  # preserves attributes so we don't want to use base lag
+  if (packageVersion("dplyr") < "0.4.2") {
+    args <- list(
+      stack_upr_ = bquote(cumsum(.(stack_var[[2]]))),
+      stack_lwr_ = bquote(lag(stack_upr_, default = 0))
+    )
+  } else {
+    args <- list(
+      stack_upr_ = bquote(cumsum(.(stack_var[[2]]))),
+      stack_lwr_ = bquote(dplyr::lag(stack_upr_, default = 0))
+    )
+  }
   x <- dplyr::mutate_(x, .dots = lazyeval::as.lazy_dots(args, asNamespace("ggvis")))
 
   dplyr::ungroup(x)
